@@ -1,6 +1,6 @@
 import pandas as pd
 import click
-from execute import *
+from xpandas.execute import *
 
 
 def get_cmd():
